pub struct NamespacedBackend { /* private fields */ }Expand description
A view of another backend restricted to a single namespace.
Implementations
Sourceimpl NamespacedBackend
impl NamespacedBackend
Sourcepub fn new(
backend: &'static dyn Backend,
namespace: &'static str,
) -> NamespacedBackend
pub fn new( backend: &'static dyn Backend, namespace: &'static str, ) -> NamespacedBackend
Create a backend that exposes only keys below namespace.