macro_rules! extend {
($target:ident) => { ... };
}Expand description
Extend a dependency’s translations with the matching crate namespace from the current crate’s backend.
Given extend!(ui_component), translations below the ui_component key in
the current crate are lazily merged with translations in the ui_component
crate. The extension takes priority for the same locale and key.
The lookup order for each locale and key is equivalent to:
app.translate(key)
.or_else(|| ui_component.translate(key))If both miss, the existing locale fallback rules continue as usual.